/**
Copyright Philipp Tölke, 2006-2007

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License version 2 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
St, Fifth Floor, Boston, MA  02110-1301  USA
**/

#include "jpegoutfile.h"
#include "error.h"

JpegOutfile::JpegOutfile() {}

int JpegOutfile::initialize(const char* outfilename, struct jpeg_error_mgr* jerr, JDIMENSION width, JDIMENSION height, int components, J_COLOR_SPACE cs) {
    if ((outfile = fopen(outfilename, "wb")) == NULL) {
        return OUTFILENOTFOUND;
    }

    cinfo.err = jpeg_std_error(jerr);

    jpeg_create_compress(&cinfo);

    jpeg_stdio_dest(&cinfo, outfile);

    cinfo.image_width = width;
    cinfo.image_height = height;
    cinfo.input_components = components;
    cinfo.in_color_space = cs;

    jpeg_set_defaults(&cinfo);

    jpeg_set_quality(&cinfo, 100, TRUE);

    jpeg_start_compress(&cinfo, TRUE);

    return 0;
}

JpegOutfile::~JpegOutfile() {


}

void JpegOutfile::destroy() {
    jpeg_finish_compress(&cinfo);
    jpeg_destroy_compress(&cinfo);
    fclose(outfile);
}

void JpegOutfile::write_scanline(JSAMPARRAY out_row) {
    (void) jpeg_write_scanlines(&cinfo, out_row, 1);
}



